"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = exports.LogLevel = void 0;
var chalk_1 = __importDefault(require("chalk"));
var util_1 = require("util");
var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["DEBUG"] = 0] = "DEBUG";
    LogLevel[LogLevel["INFO"] = 1] = "INFO";
    LogLevel[LogLevel["WARNING"] = 2] = "WARNING";
    LogLevel[LogLevel["ERROR"] = 3] = "ERROR";
    LogLevel[LogLevel["NONE"] = 4] = "NONE";
})(LogLevel = exports.LogLevel || (exports.LogLevel = {}));
var getCircularReplacer = function () {
    var seen = new WeakMap();
    return function (key, value) {
        if (typeof value === 'object' && value !== null) {
            if (seen.has(value)) {
                var representation = [];
                var firstSeen = seen.get(value);
                firstSeen && representation.push("first occurence: " + firstSeen);
                value.type && representation.push("type: " + value.type);
                value.id && representation.push("id: " + value.id);
                return "[~circle. " + representation.join(', ') + "]";
            }
            seen.set(value, key);
        }
        return value;
    };
};
var formatOutput = function () {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    args = args.map(function (entry) {
        if (typeof entry === 'object')
            return JSON.stringify(entry, getCircularReplacer());
        return entry;
    });
    return (0, util_1.inspect)(args.join(' | '), {
        showHidden: false,
        depth: null,
        colors: false,
        compact: true,
        breakLength: Infinity,
    }).replace(/\'/g, '');
};
var Logger = /** @class */ (function () {
    function Logger(logLevel, name) {
        this._logLevel = logLevel;
        this._name = name;
    }
    Object.defineProperty(Logger.prototype, "logLevel", {
        get: function () {
            return this._logLevel;
        },
        enumerable: false,
        configurable: true
    });
    Logger.prototype.debug = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (this._logLevel <= LogLevel.DEBUG) {
            console.info(chalk_1.default.gray(chalk_1.default.bgWhite.black(' DEBUG ') + " " + this._name + " | " + formatOutput.apply(void 0, args)));
        }
    };
    Logger.prototype.log = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.info(args);
    };
    Logger.prototype.info = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (this._logLevel <= LogLevel.INFO) {
            console.info(chalk_1.default.blue(chalk_1.default.bgBlue.white(' INFO ') + " " + this._name + " | " + formatOutput.apply(void 0, args)));
        }
    };
    Logger.prototype.warn = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (this._logLevel <= LogLevel.WARNING) {
            console.warn(chalk_1.default.yellow(chalk_1.default.bgYellow.black(' WARN ') + " " + this._name + " | " + formatOutput.apply(void 0, args)));
        }
    };
    Logger.prototype.error = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (this._logLevel <= LogLevel.ERROR) {
            console.error(chalk_1.default.red(chalk_1.default.bgRed.black(' ERROR ') + " " + this._name + " | " + formatOutput.apply(void 0, args)));
        }
    };
    return Logger;
}());
exports.Logger = Logger;
//# sourceMappingURL=Logger.js.map